import React, { Component } from 'react';
import Menu from './Components/Menu/Menu';
import Nav from './Components/Nav/Nav';
import Header from './Components/Header/Header';
import About from './Components/About/About';
import Projects from './Components/Projects/Projects';
import Ending from './Components/Ending/Ending';

class App extends Component {
  state = {
    menuState: false
  };

  toggleMenu = () => {
    this.setState(state => ({
      menuState: !state.menuState
        ? 'active'
        : state.menuState === 'deactive'
          ? 'active'
          : 'deactive'
    }));
  };

//This is the render method for the component. It returns a React Fragment with the Menu, Nav, Header, About, Projects, and Ending components inside. 
//It also passes the toggleMenu method and the menuState value as props to the Menu and Nav components.

  render() {
    return (
      <React.Fragment>
        <Menu toggleMenu={this.toggleMenu} showMenu={this.state.menuState} />
        <Nav toggleMenu={this.toggleMenu} showMenu={this.state.menuState} />
        <Header />
        <About />
        <Projects />
        <Ending />
      </React.Fragment>
    );
  }

  // Parallax effect. 

componentDidMount() {
  // This is a lifecycle method that is called after the component has rendered.
  
  const navbar = document.querySelector('#navbar');
  const header = document.querySelector('#welcome-section');
  const forest = document.querySelector('.forest');
  let forestInitPos = -300;
  // These lines select the elements with the specified IDs or class names and store them in variables. 
 //The forestInitPos variable is used to store the initial position of the forest element.

  window.onscroll = () => {
    let scrollPos = document.documentElement.scrollTop || document.body.scrollTop;
    // This line gets the current scroll position of the page.

    if (scrollPos <= window.innerHeight) {
      forest.style.bottom = `${parseInt(forestInitPos + scrollPos / 6)}px`;
    }
    // If the scroll position is within the viewport height, this code updates the bottom position of the forest element with a parallax effect.

    if (scrollPos - 100 <= window.innerHeight)
      header.style.visibility = header.style.visibility === 'hidden' && 'visible';
    else header.style.visibility = 'hidden';
    // If the scroll position is within 100 pixels of the viewport height, this code shows the header element. Otherwise, it hides the header element.

    if (scrollPos + 100 >= window.innerHeight) navbar.classList.add('bg-active');
    else navbar.classList.remove('bg-active');
    // If the scroll position is within 100 pixels of the viewport height, this code adds the "bg-active" class to the navbar element. Otherwise, it removes the "bg-active" class from the navbar element.
  };

    (function navSmoothScrolling() {
      const internalLinks = document.querySelectorAll('a[href^="#"]');
      for (let i in internalLinks) {
        if (internalLinks.hasOwnProperty(i)) {
          internalLinks[i].addEventListener('click', e => {
            e.preventDefault();
            document.querySelector(internalLinks[i].hash).scrollIntoView({
              block: 'start',
              behavior: 'smooth'
            });
          });
        }
      }
    })();
  }
}

export default App;
